@@ -48,7 +48,7 @@ our @EXPORT = qw(
 	
 );
 
-$Text::Reflow::VERSION = "1.11";
+$Text::Reflow::VERSION = "1.12";
 
 bootstrap Text::Reflow $Text::Reflow::VERSION;
 
@@ -479,8 +479,8 @@ sub process($) {
   # remove spaces around dashes:
   $line =~ s/([^-])[ \t]*--[ \t]*([^-])/$1--$2/g;
   # protect ". . ." ellipses:
-  $line =~ s/ \. \. \./\377\.\377\.\377\./g;
-  $line =~ s/\. \. \./\.\377\.\377\./g;
+  $line =~ s/ \. \. \./\x9F\.\x9F\.\x9F\./g;
+  $line =~ s/\. \. \./\.\x9F\.\x9F\./g;
   @linewords = split(/\s+/, $line);
   shift(@linewords) if (@linewords && ($linewords[0] eq ""));
   # If last word of previous line ends in a single hyphen,
@@ -541,7 +541,7 @@ sub reflow_para {
   @linkbreak = map { $_ > 0xF0000000 ? -((0xFFFFFFFF - $_) + 1) : $_ + 0 } @linkbreak;
   $lastbreak = shift(@linkbreak);
   compute_output();
-  grep (s/\377/ /g, @output);
+  grep (s/\x9F/ /g, @output);
   print_lines(@output);
   @words = ();
 }
